@@ -2,7 +2,7 @@ package DBIx::QuickDB::Driver::PostgreSQL;
 use strict;
 use warnings;
 
-our $VERSION = '0.000004';
+our $VERSION = '0.000005';
 
 use IPC::Cmd qw/can_run/;
 
@@ -29,6 +29,21 @@ BEGIN {
     $DBDPG    = eval { require DBD::Pg; 'DBD::Pg'};
 }
 
+sub list_env_vars {
+    my $self = shift;
+    return (
+        $self->SUPER::list_env_vars(),
+        qw{
+            PGAPPNAME PGCLIENTENCODING PGCONNECT_TIMEOUT PGDATABASE PGDATESTYLE
+            PGGEQO PGGSSLIB PGHOST PGHOSTADDR PGKRBSRVNAME PGLOCALEDIR
+            PGOPTIONS PGPASSFILE PGPASSWORD PGPORT PGREQUIREPEER PGREQUIRESSL
+            PGSERVICE PGSERVICEFILE PGSSLCERT PGSSLCOMPRESSION PGSSLCRL
+            PGSSLKEY PGSSLMODE PGSSLROOTCERT PGSYSCONFDIR PGTARGETSESSIONATTRS
+            PGTZ PGUSER
+        }
+    );
+}
+
 sub _default_paths {
     return (
         initdb   => $INITDB,
